# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-30 23:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('flexible_reports', '0006_default_ordering'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='columnorder',
            options={'verbose_name': 'Column order information', 'verbose_name_plural': 'Column order informations'},
        ),
        migrations.AddField(
            model_name='columnorder',
            name='desc',
            field=models.BooleanField(default=False, verbose_name='Descending'),
        ),
    ]
