# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-25 10:58
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('flexible_reports', '0008_auto_20171025_0553'),
    ]

    operations = [
        migrations.AlterField(
            model_name='reportelement',
            name='datasource',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='flexible_reports.Datasource', verbose_name='Datasource'),
        ),
    ]
